@@ -852,9 +852,16 @@ Gnome::Gda::Value Base_DB::auto_increment_insert_first_if_necessary(const Glib::
   else
   {
     //Return the value so that a calling function does not need to do a second SELECT.
-    value = datamodel->get_value_at(0, 0);
+    const Gnome::Gda::Value actual_value = datamodel->get_value_at(0, 0);
+    
+    //But the caller wants a numeric value not a text value
+    //(our system_autoincrements table has it as text, for future flexibility):
+    const std::string actual_value_text = actual_value.get_string();
+    bool success = false;
+    value = Conversions::parse_value(Field::TYPE_NUMERIC, actual_value_text, success, true /* iso_format */);
   }
 
+  //std::cout << "Base_DB::auto_increment_insert_first_if_necessary: returning value of type=" << value.get_value_type() << std::endl;
   return value;
 }
 
@@ -869,8 +876,8 @@ void Base_DB::recalculate_next_auto_increment_value(const Glib::ustring& table_n
   if(datamodel && datamodel->get_n_rows() && datamodel->get_n_columns())
   {
     //Increment it:
-    const Gnome::Gda::Value value_max = datamodel->get_value_at(0, 0);
-    long num_max = Utils::decimal_from_string(value_max.to_string()); //TODO: Is this sensible? Probably not.
+    const Gnome::Gda::Value value_max = datamodel->get_value_at(0, 0); // A GdaNumeric.
+    double num_max = Conversions::get_double_for_gda_value_numeric(value_max);
     ++num_max;
 
     //Set it in the glom system table:
@@ -895,8 +902,7 @@ void Base_DB::recalculate_next_auto_increment_value(const Glib::ustring& table_n
 Gnome::Gda::Value Base_DB::get_next_auto_increment_value(const Glib::ustring& table_name, const Glib::ustring& field_name) const
 {
   const Gnome::Gda::Value result = auto_increment_insert_first_if_necessary(table_name, field_name);
-  long num_result = 0;
-  num_result = Utils::decimal_from_string(result.to_string()); //TODO: Is this sensible? Probably not.
+  double num_result = Conversions::get_double_for_gda_value_numeric(result); 
 
 
   //Increment the next_value:
@@ -1078,7 +1084,7 @@ bool Base_DB::create_table_with_default_fields(const Glib::ustring& table_name)
     //query_execute( "INSERT INTO \"" + table_name + "\" VALUES (0)" );
 
     //PostgresSQL:
-    //query_execute( "CREATE TABLE " + table_name + " (\"" + primary_key_name + "\" serial NOT NULL  PRIMARY KEY)" );
+    //query_execute( "CREATE TABLE \"" + table_name + "\" (\"" + primary_key_name + "\" serial NOT NULL  PRIMARY KEY)" );
 
     //query_execute( "CREATE TABLE \"" + table_name + "\" (" +
     //  field_primary_key->get_name() + " numeric NOT NULL  PRIMARY KEY," + 
@@ -2001,8 +2007,22 @@ Base_DB::type_map_fields Base_DB::get_record_field_values_for_calculation(const
       //sharedptr<const Field> fieldPrimaryKey = get_field_primary_key();
 
       const Glib::ustring query = Utils::build_sql_select_with_key(table_name, fieldsToGet, primary_key, primary_key_value);
-      Glib::RefPtr<Gnome::Gda::DataModel> data_model = query_execute(query);
 
+      Glib::RefPtr<Gnome::Gda::DataModel> data_model;
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
+      try
+#endif
+      {
+        data_model = query_execute(query);
+      }
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
+      catch(const Glib::Exception& ex)
+      {
+        std::cerr << "Base_DB::get_record_field_values_for_calculation(): Exception while executing SQL: " << query << std::endl;
+        handle_error(ex);
+        return field_values;
+      }
+#endif
       if(data_model && data_model->get_n_rows())
       {
         int col_index = 0;
@@ -2024,7 +2044,9 @@ Base_DB::type_map_fields Base_DB::get_record_field_values_for_calculation(const
       }
       else
       {
-        handle_error();
+        //Maybe the record does not exist yet
+        //(Maybe we need the field values so we can calculate default values for some fields when creating the record.)
+        //So we create appropriate empty values below.
       }
     }
 
